package CLI::Files::Utils;

use 5.006;
use strict;
use warnings;

=head1 NAME

CLI::Files::Utils - Extra CLI utilies for handling file bunches.
'dirhier' and 'madeafter' -- Utilize them after mastering "ls -l" and "find .".

Other CLI utilities are also provided : 'colorplus', 'timeput', 'microsec'


=head1 VERSION

Version 0.11

=cut

our $VERSION = '0.11';


=head1 SUPPORT

You can find documentation for programs provided by this module as follows : 

    madeafter --help
    dirhier --help
    colorplus --help

=head1 LICENSE AND COPYRIGHT

Copyright 2018 "Toshiyuki Shimono".

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see L<http://www.gnu.org/licenses/>.


=cut

1; # End of CLI::Files::Utils
